Pērciet Lexus UX 2019 2.0 112 kW Premium pluss 2019 ar patiesu nobraukumu 19500 km Rīgā oficiālā dīlera salonā
Description: Iegādājaties mazlietotu Lexus UX ar nobraukumu 19500 km. Mazlietots Lexus UX 2019 2.0 112 kW Premium pluss Automātiskā par 33900 EUR, mazlietotu automobiļu tirdzniecības vietā Inchcape Certified Rīgā.

# Lexus UX 2019 2.0 112 kW Premium pluss, 19 500 km

25
33 900 €
(PVN nav piemērojams)
no € 357.73 / mēn.*

- Izlaiduma gads
  2019
- Virsbūves tips
  SUV
- Nobraukums
  19 500 km

- Piedziņas veids
  FWD
- Dzinējs
  Hibrīds
- Pārnesumkārba
  Automātiskā
- Dzinēja tilpums
  1987 cm3

##### JAUNUMS!

Apskatiet auto tiešsaistē, neizejot no mājām, vai sazinieties ar mums caur Whatsapp

Sazināties Whatsapp

- Tehniskie dati
- Aprīkojums
- Pamatinformācija

- Zīmols
  Lexus
- Modelis
  UX
- Modifikācija
  2019 2.0 112 kW Premium pluss
- Nobraukums
  19 500 km

- VIN
  JTHY65BH602032276
- Izlaiduma gads
  2019
- Virsbūves tips
  SUV
- Piedziņas veids
  FWD
- Pārnesumkārba
  Automātiskā

- Informācijas sistēmas
- Papildus aprīkojums
- Interjers
- Drošība
- Komforts

- Bluetooth
- Audiosistēma
- Navigācijas sistēma

- Borta dators
- Brīvroku sistēma

- Riepu spiediena kontrole
- Start-stop sistēma
- Vilkšanas āķis (noņemams)

- Ziemas pakotne
- Factory warranty
- Servisa grāmatiņa

- Otra atslēga

- Elektriski regulējami sēdekļi
- Regulējams stūres novietojums
- Multistūre

- Ātrumu pārslēdzēji pie stūres
- Apsildāmi sēdekļi
- Regulējama sēdekļu muguras daļa

- Salona apgaismojums
- Priekšējais elkoņbalsts

- Stūres pastiprinātājs
- Centrālā atslēga
- ABS pretbloķēšanas sistēma
- Gaisa spilveni
- Elektroniska rokasbremze
- Signalizācija
- Vadītāja noguruma monitorēšana
- Elektroniskā stabilitātes sistēma (ESP)

- Bremzēšanas spēka sadale
- Braukšanas joslu brīdinājuma sistēma
- Braukšanas joslu maiņu asistēšana
- Ceļa zīmju asistēšana
- Sadursmes novēršanas sistēma
- Isofix bērnu sēdeklīšu stiprinājumi
- Pretbuksēšanas sistēma (ASR)
- Lietus sensors

- LED lukturi
- Priekšējo lukturu gaismas tāluma regulēšana
- Automātiskās gaismas
- Papildu gaismas
- Gaismu aizture aizslēdzot/atslēdzot automobili
- Lasīšanas gaismas

- Klimata kontrole (trīszonu)
- Elektriski regulējami sānu spoguļi
- Elektriski atverami/aizverami stikli

- Kruīza kontrole
- Elektriska durvju aizvēršana
- Elektriska sānu durvju aizvēršana

- Parkošanās kamera
- Parkošanās sensori

## Priekšlīzinga kalkulators

Vēlaties iegādāties jaunu ikdienas sabiedroto ar līzingu?
Mēs par to esam padomājuši.
Aizpildiet šo īso pieteikuma formu un noskaidrojiet savas iespējas iegādāties auto līzingā.

Finanšu līzings

no € / mēn.*

Līzinga periods, gadi:

3 4 5 6 7

Pirmā iemaksa:

EUR
10% 20% 30% 40% 50%

Inchcape Motors Latvia SIA piedāvā finansējumu sadarbībā ar vadošajām līzinga kompānijām.

Aprēķins veikts, ņemot vērā izvēlēta automobiļa cenu finanšu līzingā ar % iemaksu uz mēnešiem.

Procentu likme 2,95% + EURIBOR (6 mēn.), administrēšanas maksa 1,5%.Aizņemies atbildīgi, izvērtējot savas iespējas atmaksāt.

Līzinga kalkulatoram ir informatīva nozīme.

## VISLABĀKIE PIEDĀVĀJUMI

ATLAIDE 6 510 €
14

### BMW 318

2019 2.0 110 kW

- 2019

- Sedans

- 38 130 km

- RWD

- Dīzeļdegviela

- Automātiskā

31 990 €
ar PVN
38 500 €
no € 337.58 / mēn.*
ATLAIDE 5 000 €
25

### Land Rover Range Rover Velar

2019 2.0 177 kW S

- 2019

- SUV

- 74 000 km

- AWD

- Dīzeļdegviela

- Automātiskā

47 900 €
ar PVN
52 900 €
no € 505.47 / mēn.*
ATLAIDE 4 200 €
25

### Jaguar F-Pace

2017 2.0 bi-turbo 177 kW F-Pce

- 2017

- SUV

- 133 500 km

- AWD

- Dīzeļdegviela

- Automātiskā

28 700 €
ar PVN
32 900 €
no € 302.86 / mēn.*
ATLAIDE 3 810 €
11

### Volvo S90

2017 2.0 FWD 110 kW

- 2017

- Sedans

- 134 000 km

- FWD

- Dīzeļdegviela

- Automātiskā

27 490 €
ar PVN
31 300 €
no € 290.09 / mēn.*
ATLAIDE 3 810 €
16

### Volkswagen Golf Sportsvan

2015 1.4 92 kW

- 2015

- Hečbeks

- 75 600 km

- FWD

- Benzīns

- Mehāniskā

11 990 €
ar PVN
15 800 €
no € 126.53 / mēn.*
ATLAIDE 3 700 €
20

### Mercedes-Benz c220

2018 2.2 RWD 125 kW T-mod

- 2018

- Universālis

- 143 088 km

- RWD

- Dīzeļdegviela

- Automātiskā

21 290 €
ar PVN
24 990 €
no € 224.67 / mēn.*

## Kāpēc iegādāties automašīnu Inchcape Certified ?

#### Padziļināta un kvalitatīva tehniskā pārbaude

Automašīnas tiek pārbaudītas atbilstoši stingriem Inchcape Certified standartiem

#### Visaptverošs, profesionālu pakalpojumu klāsts

Finansēšana, apdrošināšana, testa braucieni, un citi pakalpojumi pieejami uz vietas

#### 6 mēnešu garantija

Sešu mēnešu garantija visām automašīnām no Inchcape Certified

#### Jūsu automašīnas atpirkums (Trade-In)

Jūsu automašīna var kalpot kā pirmā iemaksa

Pieprasīt zvanu
Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.
Rezervē savu vizītes laiku!

Piesaki vizīti kādā no trim Inchcape Certified autosaloniem ātri un ērti!

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.
Pieteikums ir pieņemts, paldies
Paldies! Jūsu vizītes pieteikums ir saņemts.

Priecāsimies Jūs redzēt Inchcape Certified - pārbaudītu un uzticamu mazlietotu auto salonā!

Pieteikums AutoDNA atskaites saņemšanai
Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

## Pieteikums ONLINE auto apskatei un konsultācijai

Piesakieties automašīnas apskatei un konsultācijai tiešsaistē un gaidiet mūsu pārstāvja zvanu, kura laikā varēsiet vienoties par Jums ērtāko tiešsaistes saziņas kanālu un laiku.

ONLINE saziņas laikā prezentēsim automašīnu, sniegsim ziņas par tās aprīkojumu un tehnisko stāvokli, mūsu pakalpojumiem un finansēšanas iespējām, kā arī atbildes uz visiem Jūsu jautājumiem.

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.
NOSKATĪJI AUTO?
PIESAKTIES BEZMAKSAS TESTA BRAUCIENAM!

Piesaki sev interesējošo automobili testa braucienam un mēs parūpēsimies par laicīgu auto sagatavošanu tieši Tev!

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

## Uzzini savas auto līzinga iespējas!

Aizpildi līzinga pieteikuma formu neizejot no mājām, un uzzini par savām iespējām iegādāties auto līzingā.

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

## Uzzini savas auto līzinga iespējas!

Aizpildi līzinga pieteikuma formu neizejot no mājām, un uzzini par savām iespējām iegādāties auto līzingā.

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.
Paņem mašīnu
Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.
Pieteikums ir pieņemts, paldies
Pieteikums ir pieņemts, paldies
Paldies! Jūsu pieprasījums ir saņemts.

Priecāsimies Jūs redzēt Inchcape Certified - pārbaudītu un uzticamu mazlietotu auto salonā!

Pieteikums ir pieņemts, paldies
Pieteikums ir pieņemts, paldies
Pieteikums ir pieņemts, paldies